@@ -2,7 +2,7 @@ import logging
 
 from pysecure import log_config
 from pysecure.adapters.ssha import SshSession, SshConnect, SshSystem, \
-                                   PublicKeyHash
+                                   PublicKeyHash, ssh_pki_import_privkey_file
 from pysecure.adapters.sftpa import SftpSession, SftpFile
 
 user = 'dustin'
@@ -17,7 +17,16 @@ def connect_ssh(ssh_cb):
                 logging.debug("Ready to authenticate.")
 
                 ssh.is_server_known(allow_new=True)
-                ssh.userauth_privatekey_file(None, key_filepath, None)
+                
+                key = ssh_pki_import_privkey_file(key_filepath)
+                ssh.userauth_publickey(user, key)
+#                ssh.userauth_password(user, 'abc')
+
+# TODO: Broken. Reported.
+#                logging.debug("OpenSSH server version: %s" % (ssh.get_openssh_version()))
+#                logging.debug("SSH session status: %s" % (ssh.get_status()))
+#                logging.debug("Protocol version: %s" % (ssh.get_version()))
+#                logging.debug("Server banner: %s" % (ssh.get_serverbanner()))
 
                 ssh_cb(ssh)
 
